@@ -114,6 +114,10 @@ section. All other keys are skipped. Keys are matched with a case-insensitive
 match. Array values are always translated, unless the B<yfm_skip_array> option
 is provided.
 
+=item B<nolinting>
+
+Disable linting messages. When the source code cannot be fixed for clearer document structure, these messages are useless.
+
 =cut
 
 my %yfm_keys = ();
@@ -201,6 +205,7 @@ sub initialize {
     $self->{options}{'compat'}         = 'asciidoc';
     $self->{options}{'yfm_keys'}       = '';
     $self->{options}{'yfm_skip_array'} = 0;
+    $self->{options}{'nolinting'}      = 0;
 
     foreach my $opt ( keys %options ) {
         die wrap_mod( "po4a::asciidoc", dgettext( "po4a", "Unknown option: %s" ), $opt )
@@ -425,6 +430,10 @@ sub parse {
             } else {
                 push @comments, $line;
             }
+            do_paragraph( $self, $paragraph, $wrapped_mode );
+            $paragraph    = "";
+            $wrapped_mode = 1 unless defined( $self->{verbatim} );
+            $self->pushline( $line . "\n" );
         } elsif ( ( defined $self->{type} )
             and ( $self->{type} eq "Table" )
             and ( $line !~ m/^\|===/ )
@@ -505,7 +514,9 @@ sub parse {
                 ),
                 $paragraph,
                 $level
-            ) if ( chars( $paragraph, $self->{TT}{po_in}{encoder}, $ref ) != length($line) );
+              )
+              if ( ( chars( $paragraph, $self->{TT}{po_in}{encoder}, $ref ) != length($line) )
+                && ( !$self->{options}{'nolinting'} ) );
 
             my $t = $self->translate(
                 $paragraph,
@@ -611,7 +622,7 @@ sub parse {
                     $self->{type} = $type;
                 }
                 $paragraph = "";
-                $self->pushline( $line . "\n" ) unless defined( $self->{verbatim} ) && $self->{verbatim} == 2;
+                $self->pushline( $line . "\n" );
             }
         } elsif ( ( not defined( $self->{verbatim} ) ) and ( $line =~ m/^\/\/(.*)/ ) ) {
             my $comment = $1;
@@ -624,6 +635,11 @@ sub parse {
                 # Comment line
                 push @comments, $comment;
             }
+            do_paragraph( $self, $paragraph, $wrapped_mode ) if length($paragraph);
+            $paragraph    = "";
+            $wrapped_mode = 1;
+
+            $self->pushline( $line . "\n" );
         } elsif ( not defined $self->{verbatim}
             and ( $line =~ m/^\[\[([^\]]*)\]\]$/ ) )
         {
@@ -771,7 +787,7 @@ sub parse {
                 and ( defined( $self->{type} ) and ( $self->{type} eq "Table" ) ) )
             {
                 $paragraph .= $line . "\n";
-            } elsif (    ( $macroname eq "include" || $macroname eq "ifeval" )
+            } elsif ( ( $macroname eq "include" || $macroname eq "ifeval" )
                 and ( $macrotype eq '::' ) )
             {
                 $self->pushline( $line . "\n" );
@@ -962,7 +978,9 @@ sub parse {
                 $wrapped_mode = 0;
             }
 
-            if ( $paragraph ne "" && $self->{bullet} && length( $self->{indent} || "" ) == 0 ) {
+            if (   ( $paragraph ne "" && $self->{bullet} && length( $self->{indent} || "" ) == 0 )
+                && ( !$self->{options}{'nolinting'} ) )
+            {
 
                 # Second line of an item block is not indented. It is unindented
                 # (and allowed) additional text or a new list item.
