@@ -931,11 +931,12 @@ Overloads Transtractor's read().
 sub read {
     my $self     = shift;
     my $filename = shift;
+    my $refname  = shift;
 
     # keep the directory name of the main file.
     $my_dirname = dirname($filename);
 
-    push @{ $self->{TT}{doc_in} }, read_file( $self, $filename );
+    push @{ $self->{TT}{doc_in} }, read_file( $self, $filename, $refname );
 }
 
 =item B<read_file>
@@ -953,15 +954,16 @@ Transtractor's read.
 sub read_file {
     my $self     = shift;
     my $filename = shift
-      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Can't read from file without having a filename" ) );
+      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Cannot read from file without having a filename" ) );
+    my $refname = shift // $filename;
     my $linenum = 0;
     my @entries = ();
 
     open( my $in, $filename )
-      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Can't read from %s: %s" ), $filename, $! );
+      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Cannot read from %s: %s" ), $filename, $! );
     while ( defined( my $textline = <$in> ) ) {
         $linenum++;
-        my $ref = "$filename:$linenum";
+        my $ref = "$refname:$linenum";
 
         # TODO: add support for includeonly
         # The next regular expression matches \input or \includes that are
@@ -996,10 +998,10 @@ sub read_file {
                 my $newfilepath = <KPSEA>;
 
                 if ( $newfilename ne "" and $newfilepath eq "" ) {
-                    die wrap_mod( "po4a::tex", dgettext( "po4a", "Can't find %s with kpsewhich" ), $filename );
+                    die wrap_mod( "po4a::tex", dgettext( "po4a", "Cannot find %s with kpsewhich" ), $filename );
                 }
 
-                push @entries, read_file( $self, $newfilepath );
+                push @entries, read_file( $self, $newfilepath, $newfilename );
                 if ( $tag eq "include" ) {
                     $textline = "\\clearpage" . $end;
                 } else {
@@ -1027,7 +1029,7 @@ sub read_file {
         }
     }
     close $in
-      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Can't close %s after reading: %s" ), $filename, $! );
+      or croak wrap_mod( "po4a::tex", dgettext( "po4a", "Cannot close %s after reading: %s" ), $filename, $! );
 
     return @entries;
 }
@@ -1061,7 +1063,7 @@ sub parse_definition_file {
     }
 
     if ( !open( IN, "<$filename" ) ) {
-        warn wrap_mod( "po4a::tex", dgettext( "po4a", "Can't open %s: %s" ), $filename, $! );
+        warn wrap_mod( "po4a::tex", dgettext( "po4a", "Cannot open %s: %s" ), $filename, $! );
         if ( defined $only_try && $only_try ) {
             return;
         } else {
@@ -1105,8 +1107,7 @@ sub parse_definition_line {
                 $self->{ref},
                 "po4a::tex",
                 dgettext(
-                    "po4a",
-                    "You are using the old " . "definitions format (%s).  " . "Please update this definition line."
+                    "po4a", "You are using the old definitions format (%s).  Please update this definition line."
                 ),
                 $_[1]
             );
